Repository for Hilltop Python tools
=============================================================

This git repository contains the Hilltop Python tools and associated documentation.

Documentation
--------------
The primary documentation for the package can be found `here <http://hilltop-py.readthedocs.io>`_.

Installation
------------
hilltop-py can be installed via pip or conda::

  pip install hilltop-py

or::

  conda install -c mullenkamp hilltop-py

The main dependencies are `Pandas <http://pandas.pydata.org/pandas-docs/stable/>`_, `pywin32 <https://github.com/mhammond/pywin32>`_, and `requests <http://docs.python-requests.org>`_.
